DGLwghts: Estimate Survivor Function using Doubly Interval-Censored Failure Time Data
Description
Estimates the discrete Survivor Function from doubly interval-censored failure time data using the algorithm of De Gruttola and Lagakos.
Usage
DGLwghts(X_L, X_R, Z_L, Z_R)
Arguments
X_L
The left endpoint of the censoring interval for the initial event time
X_R
The right endpoint of the censoring interval for the initial event time
Z_L
The left endpoint of the censoring interval for the terminating event time
Z_R
The right endpoint of the censoring interval for the terminating event time
Value
DGLwghts returns a list containing the following components
x_val
A vector of mass points for initial event
w_new
A vector of estimated probabilities for x_val
t_val
A vector of mass points for terminating event
f_new
A vector of estimated probabilities for t_val
counter
Number of iterations required for convergence
Details
Set X_L = X_R if the initial event is observed. Set Z_L = Z_R if the
terminating event is observed. Set X_L = -INF if the initial event is left-censored. Set Z_R = INF if the terminating event is right-censored.
References
De Gruttola, V. and Lagakos, S. (1989). Analysis of Doubly-Censored Survival Data, with Applications to AIDS. Biometrics 45 (1): 1-11.