Sunwghts: Estimate Survivor Function using Doubly Interval-Censored Left-Truncated Failure Time Data
Description
Estimates the discrete Survivor Function from doubly interval-censored left-truncated failure time data using the algorithm of Sun.
Usage
Sunwghts(Ei, Ri, Li, Ui, Bi1, Bi2)
Arguments
Ei
The left endpoint of the censoring interval for the initial event time
Ri
The right endpoint of the censoring interval for the initial event time
Li
The left endpoint of the censoring interval for the terminating event time
Ui
The right endpoint of the censoring interval for the terminating event time
Bi1
The left endpoint of the truncation interval for the terminating event time
Bi2
The right endpoint of the truncation interval for the terminating event time
Value
Sunwghts returns a list containing the following components
uj
A vector of mass points for survival lengths
fnew
A vector of estimated probabilities for uj
counter
Number of iterations required for convergence
Details
Set Ei = Ri if the initial event is observed. Set Li = Ui if the
terminating event is observed. Set Ei = -INF if the initial event is left-censored. Set Ri = INF if the terminating event is right-censored.
References
Sun, J. (1995). Empirical Estimation of a Distribution Function with Truncated and Doubly Interval-Censored Data and Its Applications to AIDS Studies. Biometrics 51 (3): 1096-1104.